# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/storytelling/proto/story.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/storytelling/proto/story.proto',
  package='apollo.storytelling',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/storytelling/proto/story.proto\x12\x13\x61pollo.storytelling\x1a!modules/common/proto/header.proto\"5\n\x10\x43loseToCrosswalk\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\x08\x64istance\x18\x02 \x01(\x01:\x03nan\"5\n\x10\x43loseToClearArea\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\x08\x64istance\x18\x02 \x01(\x01:\x03nan\"\xa5\x01\n\x0f\x43loseToJunction\x12\n\n\x02id\x18\x01 \x01(\t\x12?\n\x04type\x18\x02 \x01(\x0e\x32\x31.apollo.storytelling.CloseToJunction.JunctionType\x12\x15\n\x08\x64istance\x18\x03 \x01(\x01:\x03nan\".\n\x0cJunctionType\x12\x10\n\x0cPNC_JUNCTION\x10\x01\x12\x0c\n\x08JUNCTION\x10\x02\"2\n\rCloseToSignal\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\x08\x64istance\x18\x02 \x01(\x01:\x03nan\"4\n\x0f\x43loseToStopSign\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\x08\x64istance\x18\x02 \x01(\x01:\x03nan\"5\n\x10\x43loseToYieldSign\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\x08\x64istance\x18\x02 \x01(\x01:\x03nan\"\xbb\x03\n\x07Stories\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x42\n\x13\x63lose_to_clear_area\x18\x02 \x01(\x0b\x32%.apollo.storytelling.CloseToClearArea\x12\x41\n\x12\x63lose_to_crosswalk\x18\x03 \x01(\x0b\x32%.apollo.storytelling.CloseToCrosswalk\x12?\n\x11\x63lose_to_junction\x18\x04 \x01(\x0b\x32$.apollo.storytelling.CloseToJunction\x12;\n\x0f\x63lose_to_signal\x18\x05 \x01(\x0b\x32\".apollo.storytelling.CloseToSignal\x12@\n\x12\x63lose_to_stop_sign\x18\x06 \x01(\x0b\x32$.apollo.storytelling.CloseToStopSign\x12\x42\n\x13\x63lose_to_yield_sign\x18\x07 \x01(\x0b\x32%.apollo.storytelling.CloseToYieldSign'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])



_CLOSETOJUNCTION_JUNCTIONTYPE = _descriptor.EnumDescriptor(
  name='JunctionType',
  full_name='apollo.storytelling.CloseToJunction.JunctionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PNC_JUNCTION', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=328,
  serialized_end=374,
)
_sym_db.RegisterEnumDescriptor(_CLOSETOJUNCTION_JUNCTIONTYPE)


_CLOSETOCROSSWALK = _descriptor.Descriptor(
  name='CloseToCrosswalk',
  full_name='apollo.storytelling.CloseToCrosswalk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.storytelling.CloseToCrosswalk.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='apollo.storytelling.CloseToCrosswalk.distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=151,
)


_CLOSETOCLEARAREA = _descriptor.Descriptor(
  name='CloseToClearArea',
  full_name='apollo.storytelling.CloseToClearArea',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.storytelling.CloseToClearArea.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='apollo.storytelling.CloseToClearArea.distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=206,
)


_CLOSETOJUNCTION = _descriptor.Descriptor(
  name='CloseToJunction',
  full_name='apollo.storytelling.CloseToJunction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.storytelling.CloseToJunction.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.storytelling.CloseToJunction.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='apollo.storytelling.CloseToJunction.distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLOSETOJUNCTION_JUNCTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=374,
)


_CLOSETOSIGNAL = _descriptor.Descriptor(
  name='CloseToSignal',
  full_name='apollo.storytelling.CloseToSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.storytelling.CloseToSignal.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='apollo.storytelling.CloseToSignal.distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=426,
)


_CLOSETOSTOPSIGN = _descriptor.Descriptor(
  name='CloseToStopSign',
  full_name='apollo.storytelling.CloseToStopSign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.storytelling.CloseToStopSign.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='apollo.storytelling.CloseToStopSign.distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=480,
)


_CLOSETOYIELDSIGN = _descriptor.Descriptor(
  name='CloseToYieldSign',
  full_name='apollo.storytelling.CloseToYieldSign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.storytelling.CloseToYieldSign.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='apollo.storytelling.CloseToYieldSign.distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=535,
)


_STORIES = _descriptor.Descriptor(
  name='Stories',
  full_name='apollo.storytelling.Stories',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.storytelling.Stories.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_to_clear_area', full_name='apollo.storytelling.Stories.close_to_clear_area', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_to_crosswalk', full_name='apollo.storytelling.Stories.close_to_crosswalk', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_to_junction', full_name='apollo.storytelling.Stories.close_to_junction', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_to_signal', full_name='apollo.storytelling.Stories.close_to_signal', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_to_stop_sign', full_name='apollo.storytelling.Stories.close_to_stop_sign', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close_to_yield_sign', full_name='apollo.storytelling.Stories.close_to_yield_sign', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=981,
)

_CLOSETOJUNCTION.fields_by_name['type'].enum_type = _CLOSETOJUNCTION_JUNCTIONTYPE
_CLOSETOJUNCTION_JUNCTIONTYPE.containing_type = _CLOSETOJUNCTION
_STORIES.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_STORIES.fields_by_name['close_to_clear_area'].message_type = _CLOSETOCLEARAREA
_STORIES.fields_by_name['close_to_crosswalk'].message_type = _CLOSETOCROSSWALK
_STORIES.fields_by_name['close_to_junction'].message_type = _CLOSETOJUNCTION
_STORIES.fields_by_name['close_to_signal'].message_type = _CLOSETOSIGNAL
_STORIES.fields_by_name['close_to_stop_sign'].message_type = _CLOSETOSTOPSIGN
_STORIES.fields_by_name['close_to_yield_sign'].message_type = _CLOSETOYIELDSIGN
DESCRIPTOR.message_types_by_name['CloseToCrosswalk'] = _CLOSETOCROSSWALK
DESCRIPTOR.message_types_by_name['CloseToClearArea'] = _CLOSETOCLEARAREA
DESCRIPTOR.message_types_by_name['CloseToJunction'] = _CLOSETOJUNCTION
DESCRIPTOR.message_types_by_name['CloseToSignal'] = _CLOSETOSIGNAL
DESCRIPTOR.message_types_by_name['CloseToStopSign'] = _CLOSETOSTOPSIGN
DESCRIPTOR.message_types_by_name['CloseToYieldSign'] = _CLOSETOYIELDSIGN
DESCRIPTOR.message_types_by_name['Stories'] = _STORIES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CloseToCrosswalk = _reflection.GeneratedProtocolMessageType('CloseToCrosswalk', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETOCROSSWALK,
  '__module__' : 'modules.storytelling.proto.story_pb2'
  # @@protoc_insertion_point(class_scope:apollo.storytelling.CloseToCrosswalk)
  })
_sym_db.RegisterMessage(CloseToCrosswalk)

CloseToClearArea = _reflection.GeneratedProtocolMessageType('CloseToClearArea', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETOCLEARAREA,
  '__module__' : 'modules.storytelling.proto.story_pb2'
  # @@protoc_insertion_point(class_scope:apollo.storytelling.CloseToClearArea)
  })
_sym_db.RegisterMessage(CloseToClearArea)

CloseToJunction = _reflection.GeneratedProtocolMessageType('CloseToJunction', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETOJUNCTION,
  '__module__' : 'modules.storytelling.proto.story_pb2'
  # @@protoc_insertion_point(class_scope:apollo.storytelling.CloseToJunction)
  })
_sym_db.RegisterMessage(CloseToJunction)

CloseToSignal = _reflection.GeneratedProtocolMessageType('CloseToSignal', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETOSIGNAL,
  '__module__' : 'modules.storytelling.proto.story_pb2'
  # @@protoc_insertion_point(class_scope:apollo.storytelling.CloseToSignal)
  })
_sym_db.RegisterMessage(CloseToSignal)

CloseToStopSign = _reflection.GeneratedProtocolMessageType('CloseToStopSign', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETOSTOPSIGN,
  '__module__' : 'modules.storytelling.proto.story_pb2'
  # @@protoc_insertion_point(class_scope:apollo.storytelling.CloseToStopSign)
  })
_sym_db.RegisterMessage(CloseToStopSign)

CloseToYieldSign = _reflection.GeneratedProtocolMessageType('CloseToYieldSign', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETOYIELDSIGN,
  '__module__' : 'modules.storytelling.proto.story_pb2'
  # @@protoc_insertion_point(class_scope:apollo.storytelling.CloseToYieldSign)
  })
_sym_db.RegisterMessage(CloseToYieldSign)

Stories = _reflection.GeneratedProtocolMessageType('Stories', (_message.Message,), {
  'DESCRIPTOR' : _STORIES,
  '__module__' : 'modules.storytelling.proto.story_pb2'
  # @@protoc_insertion_point(class_scope:apollo.storytelling.Stories)
  })
_sym_db.RegisterMessage(Stories)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/lattice_structure.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/lattice_structure.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.modules/planning/proto/lattice_structure.proto\x12\x0f\x61pollo.planning\"g\n\tStopPoint\x12\t\n\x01s\x18\x01 \x01(\x01\x12\x33\n\x04type\x18\x02 \x01(\x0e\x32\x1f.apollo.planning.StopPoint.Type:\x04HARD\"\x1a\n\x04Type\x12\x08\n\x04HARD\x10\x00\x12\x08\n\x04SOFT\x10\x01\"V\n\x0ePlanningTarget\x12.\n\nstop_point\x18\x01 \x01(\x0b\x32\x1a.apollo.planning.StopPoint\x12\x14\n\x0c\x63ruise_speed\x18\x02 \x01(\x01'
)



_STOPPOINT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.planning.StopPoint.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=144,
  serialized_end=170,
)
_sym_db.RegisterEnumDescriptor(_STOPPOINT_TYPE)


_STOPPOINT = _descriptor.Descriptor(
  name='StopPoint',
  full_name='apollo.planning.StopPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.planning.StopPoint.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.planning.StopPoint.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STOPPOINT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=170,
)


_PLANNINGTARGET = _descriptor.Descriptor(
  name='PlanningTarget',
  full_name='apollo.planning.PlanningTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_point', full_name='apollo.planning.PlanningTarget.stop_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cruise_speed', full_name='apollo.planning.PlanningTarget.cruise_speed', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=258,
)

_STOPPOINT.fields_by_name['type'].enum_type = _STOPPOINT_TYPE
_STOPPOINT_TYPE.containing_type = _STOPPOINT
_PLANNINGTARGET.fields_by_name['stop_point'].message_type = _STOPPOINT
DESCRIPTOR.message_types_by_name['StopPoint'] = _STOPPOINT
DESCRIPTOR.message_types_by_name['PlanningTarget'] = _PLANNINGTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StopPoint = _reflection.GeneratedProtocolMessageType('StopPoint', (_message.Message,), {
  'DESCRIPTOR' : _STOPPOINT,
  '__module__' : 'modules.planning.proto.lattice_structure_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.StopPoint)
  })
_sym_db.RegisterMessage(StopPoint)

PlanningTarget = _reflection.GeneratedProtocolMessageType('PlanningTarget', (_message.Message,), {
  'DESCRIPTOR' : _PLANNINGTARGET,
  '__module__' : 'modules.planning.proto.lattice_structure_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlanningTarget)
  })
_sym_db.RegisterMessage(PlanningTarget)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/guardian/proto/guardian.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.control.proto import control_cmd_pb2 as modules_dot_control_dot_proto_dot_control__cmd__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/guardian/proto/guardian.proto',
  package='apollo.guardian',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/guardian/proto/guardian.proto\x12\x0f\x61pollo.guardian\x1a!modules/common/proto/header.proto\x1a\'modules/control/proto/control_cmd.proto\"q\n\x0fGuardianCommand\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x37\n\x0f\x63ontrol_command\x18\x02 \x01(\x0b\x32\x1e.apollo.control.ControlCommand'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_control__cmd__pb2.DESCRIPTOR,])




_GUARDIANCOMMAND = _descriptor.Descriptor(
  name='GuardianCommand',
  full_name='apollo.guardian.GuardianCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.guardian.GuardianCommand.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_command', full_name='apollo.guardian.GuardianCommand.control_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=247,
)

_GUARDIANCOMMAND.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_GUARDIANCOMMAND.fields_by_name['control_command'].message_type = modules_dot_control_dot_proto_dot_control__cmd__pb2._CONTROLCOMMAND
DESCRIPTOR.message_types_by_name['GuardianCommand'] = _GUARDIANCOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GuardianCommand = _reflection.GeneratedProtocolMessageType('GuardianCommand', (_message.Message,), {
  'DESCRIPTOR' : _GUARDIANCOMMAND,
  '__module__' : 'modules.guardian.proto.guardian_pb2'
  # @@protoc_insertion_point(class_scope:apollo.guardian.GuardianCommand)
  })
_sym_db.RegisterMessage(GuardianCommand)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/perception_config_schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/perception_config_schema.proto',
  package='apollo.perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7modules/perception/proto/perception_config_schema.proto\x12\x11\x61pollo.perception\"*\n\x0bKeyValueInt\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05\"-\n\x0eKeyValueString\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"-\n\x0eKeyValueDouble\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\",\n\rKeyValueFloat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\"+\n\x0cKeyValueBool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"0\n\x10KeyValueArrayInt\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x05\"3\n\x13KeyValueArrayString\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x0c\"3\n\x13KeyValueArrayDouble\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x01\"2\n\x12KeyValueArrayFloat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x02\"1\n\x11KeyValueArrayBool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x08\"\x9c\x05\n\x10ModelConfigProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x36\n\x0einteger_params\x18\x03 \x03(\x0b\x32\x1e.apollo.perception.KeyValueInt\x12\x38\n\rstring_params\x18\x04 \x03(\x0b\x32!.apollo.perception.KeyValueString\x12\x38\n\rdouble_params\x18\x05 \x03(\x0b\x32!.apollo.perception.KeyValueDouble\x12\x36\n\x0c\x66loat_params\x18\x06 \x03(\x0b\x32 .apollo.perception.KeyValueFloat\x12\x34\n\x0b\x62ool_params\x18\x07 \x03(\x0b\x32\x1f.apollo.perception.KeyValueBool\x12\x41\n\x14\x61rray_integer_params\x18\x08 \x03(\x0b\x32#.apollo.perception.KeyValueArrayInt\x12\x43\n\x13\x61rray_string_params\x18\t \x03(\x0b\x32&.apollo.perception.KeyValueArrayString\x12\x43\n\x13\x61rray_double_params\x18\n \x03(\x0b\x32&.apollo.perception.KeyValueArrayDouble\x12\x41\n\x12\x61rray_float_params\x18\x0b \x03(\x0b\x32%.apollo.perception.KeyValueArrayFloat\x12?\n\x11\x61rray_bool_params\x18\x0c \x03(\x0b\x32$.apollo.perception.KeyValueArrayBool\"S\n\x15MultiModelConfigProto\x12:\n\rmodel_configs\x18\x01 \x03(\x0b\x32#.apollo.perception.ModelConfigProto\"5\n\x18ModelConfigFileListProto\x12\x19\n\x11model_config_path\x18\x01 \x03(\t'
)




_KEYVALUEINT = _descriptor.Descriptor(
  name='KeyValueInt',
  full_name='apollo.perception.KeyValueInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueInt.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueInt.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=120,
)


_KEYVALUESTRING = _descriptor.Descriptor(
  name='KeyValueString',
  full_name='apollo.perception.KeyValueString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueString.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueString.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=167,
)


_KEYVALUEDOUBLE = _descriptor.Descriptor(
  name='KeyValueDouble',
  full_name='apollo.perception.KeyValueDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueDouble.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueDouble.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=214,
)


_KEYVALUEFLOAT = _descriptor.Descriptor(
  name='KeyValueFloat',
  full_name='apollo.perception.KeyValueFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueFloat.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueFloat.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=260,
)


_KEYVALUEBOOL = _descriptor.Descriptor(
  name='KeyValueBool',
  full_name='apollo.perception.KeyValueBool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueBool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.perception.KeyValueBool.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=305,
)


_KEYVALUEARRAYINT = _descriptor.Descriptor(
  name='KeyValueArrayInt',
  full_name='apollo.perception.KeyValueArrayInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayInt.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayInt.values', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=307,
  serialized_end=355,
)


_KEYVALUEARRAYSTRING = _descriptor.Descriptor(
  name='KeyValueArrayString',
  full_name='apollo.perception.KeyValueArrayString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayString.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayString.values', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=408,
)


_KEYVALUEARRAYDOUBLE = _descriptor.Descriptor(
  name='KeyValueArrayDouble',
  full_name='apollo.perception.KeyValueArrayDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayDouble.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayDouble.values', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=461,
)


_KEYVALUEARRAYFLOAT = _descriptor.Descriptor(
  name='KeyValueArrayFloat',
  full_name='apollo.perception.KeyValueArrayFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayFloat.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayFloat.values', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=513,
)


_KEYVALUEARRAYBOOL = _descriptor.Descriptor(
  name='KeyValueArrayBool',
  full_name='apollo.perception.KeyValueArrayBool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.KeyValueArrayBool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='apollo.perception.KeyValueArrayBool.values', index=1,
      number=2, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=564,
)


_MODELCONFIGPROTO = _descriptor.Descriptor(
  name='ModelConfigProto',
  full_name='apollo.perception.ModelConfigProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.ModelConfigProto.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='apollo.perception.ModelConfigProto.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='integer_params', full_name='apollo.perception.ModelConfigProto.integer_params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_params', full_name='apollo.perception.ModelConfigProto.string_params', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_params', full_name='apollo.perception.ModelConfigProto.double_params', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_params', full_name='apollo.perception.ModelConfigProto.float_params', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_params', full_name='apollo.perception.ModelConfigProto.bool_params', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_integer_params', full_name='apollo.perception.ModelConfigProto.array_integer_params', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_string_params', full_name='apollo.perception.ModelConfigProto.array_string_params', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_double_params', full_name='apollo.perception.ModelConfigProto.array_double_params', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_float_params', full_name='apollo.perception.ModelConfigProto.array_float_params', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_bool_params', full_name='apollo.perception.ModelConfigProto.array_bool_params', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=1235,
)


_MULTIMODELCONFIGPROTO = _descriptor.Descriptor(
  name='MultiModelConfigProto',
  full_name='apollo.perception.MultiModelConfigProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_configs', full_name='apollo.perception.MultiModelConfigProto.model_configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1237,
  serialized_end=1320,
)


_MODELCONFIGFILELISTPROTO = _descriptor.Descriptor(
  name='ModelConfigFileListProto',
  full_name='apollo.perception.ModelConfigFileListProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_config_path', full_name='apollo.perception.ModelConfigFileListProto.model_config_path', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1322,
  serialized_end=1375,
)

_MODELCONFIGPROTO.fields_by_name['integer_params'].message_type = _KEYVALUEINT
_MODELCONFIGPROTO.fields_by_name['string_params'].message_type = _KEYVALUESTRING
_MODELCONFIGPROTO.fields_by_name['double_params'].message_type = _KEYVALUEDOUBLE
_MODELCONFIGPROTO.fields_by_name['float_params'].message_type = _KEYVALUEFLOAT
_MODELCONFIGPROTO.fields_by_name['bool_params'].message_type = _KEYVALUEBOOL
_MODELCONFIGPROTO.fields_by_name['array_integer_params'].message_type = _KEYVALUEARRAYINT
_MODELCONFIGPROTO.fields_by_name['array_string_params'].message_type = _KEYVALUEARRAYSTRING
_MODELCONFIGPROTO.fields_by_name['array_double_params'].message_type = _KEYVALUEARRAYDOUBLE
_MODELCONFIGPROTO.fields_by_name['array_float_params'].message_type = _KEYVALUEARRAYFLOAT
_MODELCONFIGPROTO.fields_by_name['array_bool_params'].message_type = _KEYVALUEARRAYBOOL
_MULTIMODELCONFIGPROTO.fields_by_name['model_configs'].message_type = _MODELCONFIGPROTO
DESCRIPTOR.message_types_by_name['KeyValueInt'] = _KEYVALUEINT
DESCRIPTOR.message_types_by_name['KeyValueString'] = _KEYVALUESTRING
DESCRIPTOR.message_types_by_name['KeyValueDouble'] = _KEYVALUEDOUBLE
DESCRIPTOR.message_types_by_name['KeyValueFloat'] = _KEYVALUEFLOAT
DESCRIPTOR.message_types_by_name['KeyValueBool'] = _KEYVALUEBOOL
DESCRIPTOR.message_types_by_name['KeyValueArrayInt'] = _KEYVALUEARRAYINT
DESCRIPTOR.message_types_by_name['KeyValueArrayString'] = _KEYVALUEARRAYSTRING
DESCRIPTOR.message_types_by_name['KeyValueArrayDouble'] = _KEYVALUEARRAYDOUBLE
DESCRIPTOR.message_types_by_name['KeyValueArrayFloat'] = _KEYVALUEARRAYFLOAT
DESCRIPTOR.message_types_by_name['KeyValueArrayBool'] = _KEYVALUEARRAYBOOL
DESCRIPTOR.message_types_by_name['ModelConfigProto'] = _MODELCONFIGPROTO
DESCRIPTOR.message_types_by_name['MultiModelConfigProto'] = _MULTIMODELCONFIGPROTO
DESCRIPTOR.message_types_by_name['ModelConfigFileListProto'] = _MODELCONFIGFILELISTPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeyValueInt = _reflection.GeneratedProtocolMessageType('KeyValueInt', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEINT,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueInt)
  })
_sym_db.RegisterMessage(KeyValueInt)

KeyValueString = _reflection.GeneratedProtocolMessageType('KeyValueString', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUESTRING,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueString)
  })
_sym_db.RegisterMessage(KeyValueString)

KeyValueDouble = _reflection.GeneratedProtocolMessageType('KeyValueDouble', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEDOUBLE,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueDouble)
  })
_sym_db.RegisterMessage(KeyValueDouble)

KeyValueFloat = _reflection.GeneratedProtocolMessageType('KeyValueFloat', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEFLOAT,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueFloat)
  })
_sym_db.RegisterMessage(KeyValueFloat)

KeyValueBool = _reflection.GeneratedProtocolMessageType('KeyValueBool', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEBOOL,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueBool)
  })
_sym_db.RegisterMessage(KeyValueBool)

KeyValueArrayInt = _reflection.GeneratedProtocolMessageType('KeyValueArrayInt', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYINT,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayInt)
  })
_sym_db.RegisterMessage(KeyValueArrayInt)

KeyValueArrayString = _reflection.GeneratedProtocolMessageType('KeyValueArrayString', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYSTRING,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayString)
  })
_sym_db.RegisterMessage(KeyValueArrayString)

KeyValueArrayDouble = _reflection.GeneratedProtocolMessageType('KeyValueArrayDouble', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYDOUBLE,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayDouble)
  })
_sym_db.RegisterMessage(KeyValueArrayDouble)

KeyValueArrayFloat = _reflection.GeneratedProtocolMessageType('KeyValueArrayFloat', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYFLOAT,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayFloat)
  })
_sym_db.RegisterMessage(KeyValueArrayFloat)

KeyValueArrayBool = _reflection.GeneratedProtocolMessageType('KeyValueArrayBool', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEARRAYBOOL,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.KeyValueArrayBool)
  })
_sym_db.RegisterMessage(KeyValueArrayBool)

ModelConfigProto = _reflection.GeneratedProtocolMessageType('ModelConfigProto', (_message.Message,), {
  'DESCRIPTOR' : _MODELCONFIGPROTO,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.ModelConfigProto)
  })
_sym_db.RegisterMessage(ModelConfigProto)

MultiModelConfigProto = _reflection.GeneratedProtocolMessageType('MultiModelConfigProto', (_message.Message,), {
  'DESCRIPTOR' : _MULTIMODELCONFIGPROTO,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.MultiModelConfigProto)
  })
_sym_db.RegisterMessage(MultiModelConfigProto)

ModelConfigFileListProto = _reflection.GeneratedProtocolMessageType('ModelConfigFileListProto', (_message.Message,), {
  'DESCRIPTOR' : _MODELCONFIGFILELISTPROTO,
  '__module__' : 'modules.perception.proto.perception_config_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.ModelConfigFileListProto)
  })
_sym_db.RegisterMessage(ModelConfigFileListProto)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/proto/map.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.map.proto import map_clear_area_pb2 as modules_dot_map_dot_proto_dot_map__clear__area__pb2
from modules.map.proto import map_crosswalk_pb2 as modules_dot_map_dot_proto_dot_map__crosswalk__pb2
from modules.map.proto import map_junction_pb2 as modules_dot_map_dot_proto_dot_map__junction__pb2
from modules.map.proto import map_lane_pb2 as modules_dot_map_dot_proto_dot_map__lane__pb2
from modules.map.proto import map_overlap_pb2 as modules_dot_map_dot_proto_dot_map__overlap__pb2
from modules.map.proto import map_signal_pb2 as modules_dot_map_dot_proto_dot_map__signal__pb2
from modules.map.proto import map_speed_bump_pb2 as modules_dot_map_dot_proto_dot_map__speed__bump__pb2
from modules.map.proto import map_stop_sign_pb2 as modules_dot_map_dot_proto_dot_map__stop__sign__pb2
from modules.map.proto import map_yield_sign_pb2 as modules_dot_map_dot_proto_dot_map__yield__sign__pb2
from modules.map.proto import map_road_pb2 as modules_dot_map_dot_proto_dot_map__road__pb2
from modules.map.proto import map_parking_space_pb2 as modules_dot_map_dot_proto_dot_map__parking__space__pb2
from modules.map.proto import map_pnc_junction_pb2 as modules_dot_map_dot_proto_dot_map__pnc__junction__pb2
from modules.map.proto import map_rsu_pb2 as modules_dot_map_dot_proto_dot_map__rsu__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/proto/map.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bmodules/map/proto/map.proto\x12\x0c\x61pollo.hdmap\x1a&modules/map/proto/map_clear_area.proto\x1a%modules/map/proto/map_crosswalk.proto\x1a$modules/map/proto/map_junction.proto\x1a modules/map/proto/map_lane.proto\x1a#modules/map/proto/map_overlap.proto\x1a\"modules/map/proto/map_signal.proto\x1a&modules/map/proto/map_speed_bump.proto\x1a%modules/map/proto/map_stop_sign.proto\x1a&modules/map/proto/map_yield_sign.proto\x1a modules/map/proto/map_road.proto\x1a)modules/map/proto/map_parking_space.proto\x1a(modules/map/proto/map_pnc_junction.proto\x1a\x1fmodules/map/proto/map_rsu.proto\"\x1a\n\nProjection\x12\x0c\n\x04proj\x18\x01 \x01(\t\"\xeb\x01\n\x06Header\x12\x0f\n\x07version\x18\x01 \x01(\x0c\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\x0c\x12,\n\nprojection\x18\x03 \x01(\x0b\x32\x18.apollo.hdmap.Projection\x12\x10\n\x08\x64istrict\x18\x04 \x01(\x0c\x12\x12\n\ngeneration\x18\x05 \x01(\x0c\x12\x11\n\trev_major\x18\x06 \x01(\x0c\x12\x11\n\trev_minor\x18\x07 \x01(\x0c\x12\x0c\n\x04left\x18\x08 \x01(\x01\x12\x0b\n\x03top\x18\t \x01(\x01\x12\r\n\x05right\x18\n \x01(\x01\x12\x0e\n\x06\x62ottom\x18\x0b \x01(\x01\x12\x0e\n\x06vendor\x18\x0c \x01(\x0c\"\xc4\x04\n\x03Map\x12$\n\x06header\x18\x01 \x01(\x0b\x32\x14.apollo.hdmap.Header\x12*\n\tcrosswalk\x18\x02 \x03(\x0b\x32\x17.apollo.hdmap.Crosswalk\x12(\n\x08junction\x18\x03 \x03(\x0b\x32\x16.apollo.hdmap.Junction\x12 \n\x04lane\x18\x04 \x03(\x0b\x32\x12.apollo.hdmap.Lane\x12)\n\tstop_sign\x18\x05 \x03(\x0b\x32\x16.apollo.hdmap.StopSign\x12$\n\x06signal\x18\x06 \x03(\x0b\x32\x14.apollo.hdmap.Signal\x12&\n\x05yield\x18\x07 \x03(\x0b\x32\x17.apollo.hdmap.YieldSign\x12&\n\x07overlap\x18\x08 \x03(\x0b\x32\x15.apollo.hdmap.Overlap\x12+\n\nclear_area\x18\t \x03(\x0b\x32\x17.apollo.hdmap.ClearArea\x12+\n\nspeed_bump\x18\n \x03(\x0b\x32\x17.apollo.hdmap.SpeedBump\x12 \n\x04road\x18\x0b \x03(\x0b\x32\x12.apollo.hdmap.Road\x12\x31\n\rparking_space\x18\x0c \x03(\x0b\x32\x1a.apollo.hdmap.ParkingSpace\x12/\n\x0cpnc_junction\x18\r \x03(\x0b\x32\x19.apollo.hdmap.PNCJunction\x12\x1e\n\x03rsu\x18\x0e \x03(\x0b\x32\x11.apollo.hdmap.RSU'
  ,
  dependencies=[modules_dot_map_dot_proto_dot_map__clear__area__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__crosswalk__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__junction__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__lane__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__overlap__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__signal__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__speed__bump__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__stop__sign__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__yield__sign__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__road__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__parking__space__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__pnc__junction__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__rsu__pb2.DESCRIPTOR,])




_PROJECTION = _descriptor.Descriptor(
  name='Projection',
  full_name='apollo.hdmap.Projection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proj', full_name='apollo.hdmap.Projection.proj', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=566,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='apollo.hdmap.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='apollo.hdmap.Header.version', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='apollo.hdmap.Header.date', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='projection', full_name='apollo.hdmap.Header.projection', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='district', full_name='apollo.hdmap.Header.district', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generation', full_name='apollo.hdmap.Header.generation', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rev_major', full_name='apollo.hdmap.Header.rev_major', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rev_minor', full_name='apollo.hdmap.Header.rev_minor', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left', full_name='apollo.hdmap.Header.left', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='top', full_name='apollo.hdmap.Header.top', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right', full_name='apollo.hdmap.Header.right', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bottom', full_name='apollo.hdmap.Header.bottom', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='apollo.hdmap.Header.vendor', index=11,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=804,
)


_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='apollo.hdmap.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.hdmap.Map.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk', full_name='apollo.hdmap.Map.crosswalk', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction', full_name='apollo.hdmap.Map.junction', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane', full_name='apollo.hdmap.Map.lane', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_sign', full_name='apollo.hdmap.Map.stop_sign', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='apollo.hdmap.Map.signal', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield', full_name='apollo.hdmap.Map.yield', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlap', full_name='apollo.hdmap.Map.overlap', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_area', full_name='apollo.hdmap.Map.clear_area', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_bump', full_name='apollo.hdmap.Map.speed_bump', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road', full_name='apollo.hdmap.Map.road', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_space', full_name='apollo.hdmap.Map.parking_space', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pnc_junction', full_name='apollo.hdmap.Map.pnc_junction', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rsu', full_name='apollo.hdmap.Map.rsu', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=1387,
)

_HEADER.fields_by_name['projection'].message_type = _PROJECTION
_MAP.fields_by_name['header'].message_type = _HEADER
_MAP.fields_by_name['crosswalk'].message_type = modules_dot_map_dot_proto_dot_map__crosswalk__pb2._CROSSWALK
_MAP.fields_by_name['junction'].message_type = modules_dot_map_dot_proto_dot_map__junction__pb2._JUNCTION
_MAP.fields_by_name['lane'].message_type = modules_dot_map_dot_proto_dot_map__lane__pb2._LANE
_MAP.fields_by_name['stop_sign'].message_type = modules_dot_map_dot_proto_dot_map__stop__sign__pb2._STOPSIGN
_MAP.fields_by_name['signal'].message_type = modules_dot_map_dot_proto_dot_map__signal__pb2._SIGNAL
_MAP.fields_by_name['yield'].message_type = modules_dot_map_dot_proto_dot_map__yield__sign__pb2._YIELDSIGN
_MAP.fields_by_name['overlap'].message_type = modules_dot_map_dot_proto_dot_map__overlap__pb2._OVERLAP
_MAP.fields_by_name['clear_area'].message_type = modules_dot_map_dot_proto_dot_map__clear__area__pb2._CLEARAREA
_MAP.fields_by_name['speed_bump'].message_type = modules_dot_map_dot_proto_dot_map__speed__bump__pb2._SPEEDBUMP
_MAP.fields_by_name['road'].message_type = modules_dot_map_dot_proto_dot_map__road__pb2._ROAD
_MAP.fields_by_name['parking_space'].message_type = modules_dot_map_dot_proto_dot_map__parking__space__pb2._PARKINGSPACE
_MAP.fields_by_name['pnc_junction'].message_type = modules_dot_map_dot_proto_dot_map__pnc__junction__pb2._PNCJUNCTION
_MAP.fields_by_name['rsu'].message_type = modules_dot_map_dot_proto_dot_map__rsu__pb2._RSU
DESCRIPTOR.message_types_by_name['Projection'] = _PROJECTION
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Map'] = _MAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Projection = _reflection.GeneratedProtocolMessageType('Projection', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTION,
  '__module__' : 'modules.map.proto.map_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Projection)
  })
_sym_db.RegisterMessage(Projection)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'modules.map.proto.map_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Header)
  })
_sym_db.RegisterMessage(Header)

Map = _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {
  'DESCRIPTOR' : _MAP,
  '__module__' : 'modules.map.proto.map_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Map)
  })
_sym_db.RegisterMessage(Map)


# @@protoc_insertion_point(module_scope)
